@@ -4,10 +4,11 @@ use url::Url;
 use env_logger::Builder;
 use log::LevelFilter;
 
-use tungstenite::client::connect_with_config;
-use tungstenite::extensions::deflate::{DeflateConfigBuilder, DeflateExt};
-use tungstenite::protocol::WebSocketConfig;
-use tungstenite::{connect, Error, Message, Result};
+use ws_test::client::connect_with_config;
+use ws_test::extensions::deflate::{DeflateConfigBuilder, DeflateExt};
+use ws_test::protocol::WebSocketConfig;
+use ws_test::{connect, Error, Message, Result};
+
 fn main() {
     let mut builder = Builder::new();
     builder.filter_level(LevelFilter::Trace);
